self: super: {

  # change GIT version
  # latest supported are in: https://github.com/NixOS/nixpkgs/tree/master/pkgs/applications/version-management/git-and-tools/git
  git = super.lib.overrideDerivation super.git (oldAttrs: {
    name = "git-2.25.3";
    src = self.fetchurl {
      url = "https://www.kernel.org/pub/software/scm/git/git-2.25.3.tar.xz";
      sha256 = "0yvr97cl0dvj3fwblq1mb0cp97v8hrn9l98p8b1jx8815mbsnz9h";
    };

    # patches come from: https://github.com/NixOS/nixpkgs/tree/master/pkgs/applications/version-management/git-and-tools/git
    patches = [
      ./patches/git/docbook2texi.patch
      ./patches/git/git-sh-i18n.patch
      ./patches/git/ssh-path.patch
      ./patches/git/git-send-email-honor-PATH.patch
      ./patches/git/installCheck-path.patch
    ];

  });

  libgit2rc = super.lib.overrideDerivation super.libgit2 (oldAttrs: {
    name = "libgit2-1.0.1";
    version = "1.0.1";

    src = self.fetchFromGitHub {
        owner = "libgit2";
        repo = "libgit2";
        rev = "v1.0.1";
        sha256 = "0xqdnvrq1bnf8hxh9xjw25y2cg91agvd9jr5qwd30z2a0dzll22v";
    };

    cmakeFlags = [ "-DTHREADSAFE=ON" "-DUSE_HTTPS=no"];

    buildInputs = [
        super.zlib
        super.libssh2
        super.openssl
        super.curl
    ];

  });

  # Override subversion derivation to
  #  - activate special python bindings
  subversionrc =

  let
    py3c = self.python38Packages.buildPythonPackage rec {
        pname = "py3c";
        version = "1.1";
        src = self.fetchurl {
          url = "https://github.com/encukou/py3c/archive/v1.1.tar.gz";
          sha256 = "086xxccgzr4zkhsjkbcakydghrmll3rkxdcxhp5d1pidr4mw5zy7";
        };
        format = "setuptools";
        doCheck = false;
        buildInputs = [];
        checkInputs = [];
        nativeBuildInputs = [];
        propagatedBuildInputs = [];
        meta = {
          license = [  ];
        };

        preBuild = ''
            make install
        '';
    };

    pythonWithEnv = self.python38Packages.python.buildEnv.override {
        extraLibs = [ py3c ];
    };

    subversionWithPython = super.subversion.override {
      httpSupport = true; # client must support http
      pythonBindings = true;
      python = pythonWithEnv;
    };

  in
    super.lib.overrideDerivation subversionWithPython (oldAttrs: {
      name = "subversion-1.14.0";
      src = self.fetchurl {
        url = "https://archive.apache.org/dist/subversion/subversion-1.14.0.tar.gz";
        sha256 = "1l1px5kva5a13pi2rkxfgxfvypvl6bmbkdag6168fhayad3i2ggg";
      };

      ## use internal lz4/utf8proc because it is stable and shipped with SVN
      configureFlags = oldAttrs.configureFlags ++ [
        " --with-lz4=internal"
        " --with-utf8proc=internal"
        " --with-py3c=${py3c}/include/python3.8/py3c/"
      ];
  });



}
